@@ -28,7 +28,7 @@
 #include "settings.h"
 
 #include <QDBusReply>
-#include <qvariant.h>
+#include <qicon.h>
 
 #include <klocalizedstring.h>
 #include <kdesktopfile.h>
@@ -368,12 +368,22 @@ static QString getIconNameFromPlayerId(const QString &id)
 	if (id.startsWith(QLatin1String("xmms"))) return ("xmms");
 	if (id.startsWith(QLatin1String("tomahawk"))) return ("tomahawk");
 	if (id.startsWith(QLatin1String("clementine"))) return ("application-x-clementine");
-	// Surprisingly...
-	if (id.startsWith(QLatin1String("chrome"))) return ("chrome-browser");
-	if (id.startsWith(QLatin1String("chromium"))) return ("chromium-browser");
+
+	// Partially supports MPRIS2 from version 75 onwards.
+	// Some systems seem to have really old icon names.
+	if (id.startsWith(QLatin1String("firefox"))) return ("firefox;netscape");
+
+	// Surprisingly, claims to support MPRIS2 but does not fully.
+	// The installed icon name may vary depending on whether the application
+	// is really Chrome or Chromium.
+	if (id.startsWith(QLatin1String("chrome")) || id.startsWith(QLatin1String("chromium")))
+		return ("chromium-browser;chrome-browser;google-chrome");
+
 	// Uses QtWebEngine which is based on Chromium, so as above...
 	if (id.startsWith(QLatin1String("akregator"))) return ("akregator");
+	if (id.startsWith(QLatin1String("konqueror"))) return ("konqueror");
 
+	qCDebug(KMIX_LOG) << "no desktop file or known icon for" << id;
 	return (QString());				// no application known
 }
 
