@@ -25,7 +25,6 @@
 
 #include <klocalizedstring.h>
 
-#include "core/ControlPool.h"
 #include "core/mixer.h"
 #include "dbus/dbuscontrolwrapper.h"
 #include "gui/guiprofile.h"
@@ -158,8 +157,7 @@ shared_ptr<MixDevice> MixDevice::addToPool()
 {
 //	qCDebug(KMIX_LOG) << "id=" <<  _mixer->id() << ":" << _id;
     shared_ptr<MixDevice> thisSharedPtr(this);
-    //shared_ptr<MixDevice> thisSharedPtr = ControlPool::instance()->add(fullyQualifiedId, this);
-    _dbusControlWrapper = new DBusControlWrapper( thisSharedPtr, dbusPath() );
+    _dbusControlWrapper = new DBusControlWrapper(thisSharedPtr, dbusPath());
     return (thisSharedPtr);
 }
 
@@ -395,11 +393,11 @@ bool MixDevice::write(KConfig *config, const QString &grp)
 void MixDevice::writePlaybackOrCapture(KConfigGroup& config, bool capture)
 {
     Volume& volume = capture ? captureVolume() : playbackVolume();
-    foreach (VolumeChannel vc, volume.getVolumes() )
-    {
-        config.writeEntry(getVolString(vc.chid,capture), static_cast<int>(vc.volume));
-    } // for all channels
-
+    const QMap<Volume::ChannelID, VolumeChannel> volumes = volume.getVolumes();
+    for (const VolumeChannel &vc : volumes)
+    {							// for all channels
+        config.writeEntry(getVolString(vc.chid, capture), static_cast<int>(vc.volume));
+    }
 }
 
 QString MixDevice::getVolString(Volume::ChannelID chid, bool capture)
