@@ -25,10 +25,10 @@
 #include <klocalizedstring.h>
 #include <kconfig.h>
 
+#include "settings.h"
 #include "backends/mixer_backend.h"
 #include "backends/kmix-backends.cpp"
 #include "core/ControlManager.h"
-#include "core/GlobalConfig.h"
 #include "core/volume.h"
 
 /**
@@ -66,7 +66,7 @@ MasterControl Mixer::_globalMasterPreferred;
  */
 /* static */ bool Mixer::dynamicBackendsPresent()
 {
-    foreach (const Mixer *mixer, s_mixers)
+    for (const Mixer *mixer : qAsConst(s_mixers))
     {
         if (mixer->isDynamic()) return (true);
     }
@@ -75,7 +75,7 @@ MasterControl Mixer::_globalMasterPreferred;
 
 /* static */ bool Mixer::pulseaudioPresent()
 {
-    foreach (const Mixer *mixer, s_mixers)
+    for (const Mixer *mixer : qAsConst(s_mixers))
     {
         if (mixer->getDriverName()=="PulseAudio") return (true);
     }
@@ -409,7 +409,7 @@ QString Mixer::getBaseName() const
 
 /* static */ Mixer *Mixer::getGlobalMasterMixerNoFalback()
 {
-    foreach (Mixer *mixer, Mixer::mixers())
+    for (Mixer *mixer : qAsConst(s_mixers))
     {
         if (mixer!=nullptr && mixer->id()==_globalMasterCurrent.getCard())
             return mixer;
@@ -468,7 +468,7 @@ QString Mixer::getBaseName() const
 		return mixer->_mixerBackend->recommendedMaster();
 	}
 
-	foreach (shared_ptr<MixDevice> md, mixer->_mixerBackend->m_mixDevices )
+	for (const shared_ptr<MixDevice> md : qAsConst(mixer->_mixerBackend->m_mixDevices))
 	{
 		if (!md) continue; // invalid
 
@@ -513,10 +513,10 @@ void Mixer::setLocalMasterMD(const QString &devPK)
 }
 
 
-shared_ptr<MixDevice> Mixer::find(const QString& mixdeviceID) const
+shared_ptr<MixDevice> Mixer::find(const QString &mixdeviceID) const
 {
 	shared_ptr<MixDevice> mdRet;
-	foreach (shared_ptr<MixDevice> md, _mixerBackend->m_mixDevices)
+	for (const shared_ptr<MixDevice> md : qAsConst(_mixerBackend->m_mixDevices))
 	{
 		if (!md) continue; // invalid
 		if (md->id()==mixdeviceID)
@@ -561,12 +561,12 @@ void Mixer::commitVolumeChange(shared_ptr<MixDevice> md)
 		// We also cannot rely on a notification from the driver (SocketNotifier), because
 		// nothing has changed, and so there s nothing to notify.
 		_mixerBackend->readSetFromHWforceUpdate();
-		if (GlobalConfig::instance().data.debugControlManager)
+		if (Settings::debugControlManager())
 			qCDebug(KMIX_LOG)
 			<< "committing a control with capture volume, that might announce: " << md->id();
 		_mixerBackend->readSetFromHW();
 	}
-	if (GlobalConfig::instance().data.debugControlManager)
+	if (Settings::debugControlManager())
 		qCDebug(KMIX_LOG)
 		<< "committing announces the change of: " << md->id();
 
@@ -647,10 +647,3 @@ QString Mixer::iconName() const
     if (master!=nullptr) return (master->iconName());
     return ("media-playback-start");			// fallback default icon
 }
-
-
-/* static */ bool Mixer::getBeepOnVolumeChange()
-{
-    GlobalConfigData &gcd = GlobalConfig::instance().data;
-    return (gcd.beepOnVolumeChange);
-}
