@@ -82,8 +82,11 @@ void DialogChooseBackends::createPage(const QSet<QString> &mixerIds)
 #endif
 	bool hasMixerFilter = !mixerIds.isEmpty();
 	qCDebug(KMIX_LOG) << "MixerIds=" << mixerIds;
-	for (const Mixer *mixer : Mixer::mixers())
+	for (const Mixer *mixer : qAsConst(Mixer::mixers()))
 	{
+            // TODO: No point in showing mixers which do not have any volume controls.
+            // See checks done in ViewDockAreaPopup::initLayout()
+
             QListWidgetItem *item = new QListWidgetItem(m_mixerList);
             item->setText(mixer->readableName(true));
             item->setSizeHint(QSize(1, 16));
