@@ -50,49 +50,38 @@ public:
     MDWSlider(shared_ptr<MixDevice> md, MixDeviceWidget::MDWFlags flags, ViewBase *view, ProfControl *pctl = nullptr);
     virtual ~MDWSlider();
 
-    enum LabelType { LT_ALL, LT_FIRST_CAPTURE, LT_NONE };
-    void addActionToPopup( QAction *action );
-    void createActions();
-    void createShortcutActions();
-    
     // GUI
-    bool isStereoLinked() const override { return m_linked; }
-    void setStereoLinked( bool value ) override;
-    void setLabeled( bool value ) override;
-    void setTicks( bool ticks ) override;
-    void setIcons( bool value ) override;
+    bool isStereoLinked() const override		{ return (m_linked); }
+    void setStereoLinked(bool value) override;
+
+    void setLabeled(bool value) override;
+    void setTicks(bool ticks) override;
+    void setIcons(bool value) override;
 
     QToolButton* addMediaButton(QString iconName, QLayout* layout, QWidget *parent);
     void updateMediaButton();
-    void setColors( QColor high, QColor low, QColor back ) override;
-    void setMutedColors( QColor high, QColor low, QColor back ) override;
     
-    bool eventFilter(QObject *obj, QEvent *ev) override;
-
     QString iconName();
     // Layout
     QSizePolicy sizePolicy() const;
 	QSize sizeHint() const override;
     int labelExtentHint() const override;
     void setLabelExtent(int extent) override;
-	bool hasMuteButton() const;
-	bool hasCaptureLED() const;
-
-	static bool debugMe;
 
 public slots:
     void toggleRecsrc();
     void toggleMuted();
     void toggleStereoLinked();
 
-    void setDisabled( bool value ) override;
     void update() override;
-    void showMoveMenu();
-    void showContextMenu( const QPoint &pos = QCursor::pos() ) override;
     void increaseOrDecreaseVolume(bool arg1, Volume::VolumeTypeFlag volumeType);
-    VolumeSliderExtraData& extraData(QAbstractSlider *slider);
     void addMediaControls(QBoxLayout* arg1);
 
+protected:
+    void createContextMenu(QMenu *menu) override;
+
+    bool eventFilter(QObject *obj, QEvent *ev) override;
+
 private slots:
     void setRecsrc(bool value);
     void setMuted(bool value);
@@ -107,10 +96,14 @@ private slots:
     void mediaNext(bool);
     void mediaPrev(bool);
 
+    void showMoveMenu();
     void moveStream(bool checked);
 
 private:
     void createWidgets();
+    void createActions();
+    void createGlobalActions();
+
     void addSliders(QBoxLayout *volLayout, char type, Volume& vol,
                      QList<QAbstractSlider *>& ref_sliders, const QString &tooltipText );
 
@@ -123,13 +116,15 @@ private:
     void updateAccesability();
 #endif
 
+    bool hasMuteButton() const				{ return (m_muteButton!=nullptr); }
+    bool hasCaptureLED() const				{ return (m_captureButton!=nullptr); }
+
 	QString calculatePlaybackIcon(MediaController::PlayState playState);
 	QWidget *guiAddButtonSpacer();
 	void guiAddCaptureButton(const QString &captureTooltipText);
 	void guiAddMuteButton(const QString &muteTooltipText);
 	void guiAddControlIcon(const QString &tooltipText);
 	void guiAddControlLabel(Qt::Alignment alignment, const QString &channelName);
-	void addGlobalShortcut(QAction* action, const QString& label, bool dynamicControl);
     QSize controlButtonSize();
 
     bool m_linked;
