@@ -42,7 +42,6 @@ class MixDeviceWidget : public QWidget
 public:
     enum MDWFlag
     {
-        SmallSize = 0x01,
         ShowMute = 0x02,
         ShowCapture = 0x04,
         ShowMixerName = 0x08
@@ -76,14 +75,10 @@ signals:
     void guiVisibilityChange(MixDeviceWidget* source, bool enable);
 
 protected slots:
-    virtual void showContextMenu(const QPoint &pos = QCursor::pos()) = 0;
-    virtual void setDisabled(bool value) = 0;
-
-    virtual void defineKeys();
     void volumeChange(int);
 
 protected:
-    void addActionToPopup(QAction *action);
+    virtual void createContextMenu(QMenu *menu) = 0;
     void contextMenuEvent(QContextMenuEvent *ev) override;
 
     Qt::Orientation orientation() const			{ return (m_view->orientation()); }
@@ -91,9 +86,11 @@ protected:
     ViewBase *view() const				{ return (m_view); }
     ProfControl *profileControl() const			{ return (m_pctl); }
 
-protected:
-      KActionCollection*   _mdwActions;
-      KActionCollection*   _mdwPopupActions;
+    KActionCollection *channelActions() const		{ return (m_channelActions); }
+    KActionCollection *globalActions() const		{ return (m_globalActions); }
+
+private slots:
+    void configureShortcuts();
 
 private:
       MDWFlags m_flags;
@@ -101,6 +98,9 @@ private:
       ProfControl *m_pctl;
       ViewBase *m_view;
       KShortcutsDialog *m_shortcutsDialog;
+
+      KActionCollection *m_channelActions;
+      KActionCollection *m_globalActions;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(MixDeviceWidget::MDWFlags)
