@@ -34,9 +34,9 @@
 #include <klocalizedstring.h>
 #include <kwindowsystem.h>
 #include <kglobalaccel.h>
+#include <kxmlguiwindow.h>
 
 // KMix
-#include "apps/kmix.h"
 #include "core/mixer.h"
 #include "core/ControlManager.h"
 #include "gui/dialogchoosebackends.h"
@@ -44,13 +44,14 @@
 #include "gui/kmixprefdlg.h"
 #include "gui/mdwslider.h"
 #include "dialogbase.h"
+#include "settings.h"
 
 // Restore volume button feature is incomplete => disabling for KDE 4.10
 #undef RESTORE_VOLUME_BUTTON
 
 
 ViewDockAreaPopup::ViewDockAreaPopup(QWidget* parent, const QString &id, ViewBase::ViewFlags vflags,
-				     const QString &guiProfileId, KMixWindow *dockW)
+				     const QString &guiProfileId, KXmlGuiWindow *dockW)
 	: ViewBase(parent, id, {}, vflags, guiProfileId),
 	  _kmixMainWindow(dockW)
 {
@@ -299,7 +300,7 @@ Application: KMix (kmix), signal: Segmentation fault
 	// setting it once in the constructor.
 	clearMixers();
 
-	QSet<QString> preferredMixersForSoundmenu = GlobalConfig::instance().getMixersForSoundmenu();
+	const QStringList preferredMixersForSoundmenu = Settings::mixersForSoundMenu();
 	//qCDebug(KMIX_LOG) << "Launch with " << preferredMixersForSoundmenu;
 	for (Mixer *mixer : qAsConst(Mixer::mixers()))
 	{
@@ -432,9 +433,10 @@ _layoutMDW->addWidget( seperatorBetweenMastersAndStreams, row, col );
    return mdw;
 }
 
+
 void ViewDockAreaPopup::constructionFinished()
 {
-//   qCDebug(KMIX_LOG) << "ViewDockAreaPopup::constructionFinished()\n";
+	//qCDebug(KMIX_LOG);
 
 	mainWindowButton = new QPushButton(QIcon::fromTheme("show-mixer"), "" , this);
 	mainWindowButton->setObjectName(QLatin1String("MixerPanel"));
@@ -460,17 +462,12 @@ void ViewDockAreaPopup::constructionFinished()
 	int sliderRow = _layoutMDW->rowCount();
 	_layoutMDW->addLayout(optionsLayout, sliderRow, 0, 1, _layoutMDW->columnCount());
 
+	// The controls layout needs to be adjusted after the popup has been shown.
+	QTimer::singleShot(0, this, [this](){ adjustControlsLayout(); });
 	updateGuiOptions();
-
-	_layoutMDW->update();
-	_layoutMDW->activate();
-
-    //bool fnc = focusNextChild();
-    //qCWarning(KMIX_LOG) << "fnc=" <<fnc;
-
-//	qCDebug(KMIX_LOG) << "F layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
 }
 
+
 QPushButton* ViewDockAreaPopup::createRestoreVolumeButton ( int storageSlot )
 {
 	QString buttonText = QString("%1").arg(storageSlot);
@@ -494,10 +491,10 @@ void ViewDockAreaPopup::refreshVolumeLevels()
 
 void ViewDockAreaPopup::configureView()
 {
-	KMixPrefDlg *prefDlg = KMixPrefDlg::getInstance();
-	prefDlg->switchToPage(KMixPrefDlg::PrefSoundMenu);
+	KMixPrefDlg::instance()->showAtPage(KMixPrefDlg::PageVolumeControl);
 }
 
+
 /**
  * This gets activated when a user clicks the "Mixer" PushButton in this popup.
  */
@@ -507,11 +504,11 @@ void ViewDockAreaPopup::showPanelSlot()
     KWindowSystem::setOnDesktop(_kmixMainWindow->winId(), KWindowSystem::currentDesktop());
     KWindowSystem::activateWindow(_kmixMainWindow->winId());
     // This is only needed when the window is already visible.
-    static_cast<QWidget*>(parent())->hide();
+    static_cast<QWidget *>(parent())->hide();
 }
 
 
 Qt::Orientation ViewDockAreaPopup::orientationSetting() const
 {
-	return (GlobalConfig::instance().data.getTraypopupOrientation());
+	return (static_cast<Qt::Orientation>(Settings::orientationTrayPopup()));
 }
